@@ -1,6 +1,6 @@
 /* awindow.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2016 Ralf Hoffmann.
+ * Copyright (C) 2001-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -190,6 +190,11 @@ public:
   void forceOpenPosition( int x, int y,
                           bool max_h,
                           bool max_v );
+
+  void enableXDND();
+  bool acceptXDND();
+
+  Widget *findWidgetForRootPos( int rx, int ry );
 protected:
   bool onScreen;
   int _bg;
@@ -245,9 +250,11 @@ private:
 
   void addKeyCallBack( AWindow *subwin, CallBack *new_cb, int mode = 0 );
   void removeKeyCallBack( AWindow *subwin, CallBack *cb );
+  Window findWindowForRootPos( int rx, int ry );
 
   bool _callback_forbidden;
   wm_window_type_t m_window_type;
+  bool m_enable_xdnd;
 };
 
 #endif
