@@ -424,7 +424,7 @@ bool PopUpMenu::handleMessage( XEvent *e,Message *msg )
                         }
                     }
                 
-                    setHighlightEntry( forwardToVisibleEntry( highlighted_entry, 1 ) );
+                    setHighlightEntry( highlighted_entry );
                 } else if ( msg->key == XK_Up ) {
                     int highlighted_entry;
 
@@ -437,7 +437,7 @@ bool PopUpMenu::handleMessage( XEvent *e,Message *msg )
                         }
                     }
 
-                    setHighlightEntry( forwardToVisibleEntry( highlighted_entry, -1 ) );
+                    setHighlightEntry( highlighted_entry, -1 );
                 } else if ( msg->key == XK_Return ) {
                     activateEntry( m_highlighted_entry );
                 } else if ( msg->key == XK_Right ) {
@@ -504,7 +504,7 @@ bool PopUpMenu::handleMessage( XEvent *e,Message *msg )
                   entry = getEntryForYPos( my );
                   if ( entry >= 0 && entry < (int)m_entries.size() ) {
                       if ( m_highlighted_entry != entry && isVisibleEntry( entry ) == true ) {
-                          setHighlightEntry( entry );
+                          setHighlightEntry( entry, 0 );
                           
                           changeFocusTo( this );
                       }
@@ -631,13 +631,17 @@ void PopUpMenu::activateEntry( int entry )
     return;
 }
 
-void PopUpMenu::setHighlightEntry( int entry )
+void PopUpMenu::setHighlightEntry( int entry, int forward_direction )
 {
     if ( entry >= 0 && entry < (int)m_entries.size() ) {
         if ( m_highlighted_entry != entry ) {
             m_open_after_timeout = true;
             m_highlighted_entry = entry;
-            m_highlighted_entry = forwardToVisibleEntry( m_highlighted_entry, 1 );
+
+            if ( forward_direction != 0 ) {
+                m_highlighted_entry = forwardToVisibleEntry( m_highlighted_entry, forward_direction );
+            }
+
             m_counter = 0;
             
             enableTimer();
@@ -909,7 +913,7 @@ int PopUpMenu::forwardToVisibleEntry( int pos, int direction )
 void PopUpMenu::updateInfixFilter()
 {
     //move highlight to next visible
-    setHighlightEntry( forwardToVisibleEntry( m_highlighted_entry, 1 ) );
+    setHighlightEntry( m_highlighted_entry );
 }
 
 bool PopUpMenu::isVisibleEntry( int pos ) const
