@@ -1227,18 +1227,18 @@ void TextView::copySelectionToClipboard()
     if ( unwrapped_start_line >= 0 && unwrapped_end_line >= unwrapped_start_line ) {
 
         if ( unwrapped_start_line == unwrapped_end_line ) {
-            ts.getUnwrappedLine( unwrapped_start_line,
-                                 unwrapped_start_offset,
-                                 unwrapped_end_offset - unwrapped_start_offset, s );
+            ts.getUnwrappedLineRaw( unwrapped_start_line,
+                                    unwrapped_start_offset,
+                                    unwrapped_end_offset - unwrapped_start_offset, s );
         } else {
-            ts.getUnwrappedLine( unwrapped_start_line,
-                                 unwrapped_start_offset, s );
+            ts.getUnwrappedLineRaw( unwrapped_start_line,
+                                    unwrapped_start_offset, s );
 
             std::string temp_line_str;
 
             // all full lines between start and end
             for ( int l = unwrapped_start_line + 1; l < unwrapped_end_line; l++ ) {
-                ts.getUnwrappedLine( l, 0, temp_line_str );
+                ts.getUnwrappedLineRaw( l, 0, temp_line_str );
 
                 s += '\n';
 
@@ -1246,7 +1246,7 @@ void TextView::copySelectionToClipboard()
             }
 
             // and the rest up to the end offset
-            ts.getUnwrappedLine( unwrapped_end_line, 0, unwrapped_end_offset, temp_line_str );
+            ts.getUnwrappedLineRaw( unwrapped_end_line, 0, unwrapped_end_offset, temp_line_str );
 
             s += '\n';
 
