@@ -1,6 +1,6 @@
 /* util.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2016 Ralf Hoffmann.
+ * Copyright (C) 2001-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -417,6 +417,29 @@ namespace AGUIXUtils
         str.resize( pos + 1 );
     }
 
+    bool char_in_string( const char ch,
+                         const std::string &str )
+    {
+        for ( auto &str_ch : str ) {
+            if ( ch == str_ch ) return true;
+        }
+
+        return false;
+    }
+    
+    void rstrip( std::string &str, const std::string &strip_chars )
+    {
+        if ( str.empty() ) return;
+
+        int pos = str.length() - 1;
+
+        for ( pos = str.length() - 1;
+              pos >= 0 && char_in_string( str[pos], strip_chars );
+              pos-- );
+
+        str.resize( pos + 1 );
+    }
+
     void strip( std::string &str )
     {
         if ( str.empty() ) return;
@@ -484,4 +507,64 @@ namespace AGUIXUtils
 
         return true;
     }
+
+    std::string escape_uri( const std::string &uri )
+    {
+        std::string res;
+
+        for ( auto &ch : uri ) {
+            if ( std::isalnum( ch ) ||
+                 ch == '-' ||
+                 ch == '_' ||
+                 ch == '.' ||
+                 ch == '!' ||
+                 ch == '~' ||
+                 ch == '*' ||
+                 ch == '\'' ||
+                 ch == '(' ||
+                 ch == ')' ||
+                 ch == '/' ) {
+                res += ch;
+            } else {
+                res += formatStringToString( "%%%02x", ch );
+            }
+        }
+
+        return res;
+    }
+
+    std::string unescape_uri( const std::string &uri )
+    {
+        std::string res;
+
+        for ( size_t pos = 0; pos < uri.length(); pos++ ) {
+            if ( uri[pos] != '%' ) {
+                res += uri[pos];
+            } else {
+                if ( pos + 2 >= uri.length() ) return "";
+
+                int ch[2] = { std::tolower( uri[ pos + 1 ] ),
+                              std::tolower( uri[ pos + 2 ] ) };
+                char unescaped_ch = 0;
+
+                for ( size_t run = 0; run < 2; run++ ) {
+                    unescaped_ch <<= 4;
+
+                    if ( ch[run] >= '0' && ch[run] <= '9' ) {
+                        unescaped_ch |= ch[run] - '0';
+                    } else if ( ch[run] >= 'a' && ch[run] <= 'f' ) {
+                        unescaped_ch |= 10 + ch[run] - 'a';
+                    } else {
+                        return "";
+                    }
+                }
+
+                res += unescaped_ch;
+
+                pos += 2;
+            }
+        }
+
+        return res;
+    }
 }
