@@ -1,6 +1,6 @@
 /* util.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2016 Ralf Hoffmann.
+ * Copyright (C) 2001-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -107,12 +107,19 @@ namespace AGUIXUtils
     bool ends_with( const std::string &str,
                     const std::string &suffix );
 
+    bool char_in_string( const char ch,
+                         const std::string &str );
+
     void rstrip( std::string &str );
+    void rstrip( std::string &str, const std::string &strip_chars );
     void strip( std::string &str );
 
     std::string timeToString( time_t t );
     bool parseStringToTime( const std::string &time_string,
                             time_t *return_time );
+
+    std::string escape_uri( const std::string &uri );
+    std::string unescape_uri( const std::string &uri );
 }
 
 #define TIMEMEASURE_T struct timeval
