@@ -1,6 +1,6 @@
 /* configtokens.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2003-2016 Ralf Hoffmann.
+ * Copyright (C) 2003-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -432,7 +432,8 @@ struct mytoken tokenlist[]={
   { PATTERNISCOMMASEPARATED_WCP, "pattern_is_comma_separated" },
   { USE_STRING_COMPARE_MODE_WCP, "usestringcomparemode" },
   { STRCASECMP_WCP, "strcasecmp" },
-  { VIEWNEWESTFILESOP_WCP, "viewnewestfilesop" }
+  { VIEWNEWESTFILESOP_WCP, "viewnewestfilesop" },
+  { SHOWRECENT_WCP, "showrecent" }
 };
 
 ArrayList *tokenlist_sorted = NULL;
