@@ -168,7 +168,7 @@ void ExeClass::execute()
   fp = NULL;
 
   if ( error == 0 ) {
-      (void)system( exestr.c_str() );
+      int tres __attribute__((unused)) = system( exestr.c_str() );
   } else {
     //TODO show requests?
   }
