@@ -1,6 +1,6 @@
 /* nwcentryselectionstate.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2013 Ralf Hoffmann.
+ * Copyright (C) 2013-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -149,6 +149,23 @@ WCFiletype *NWCEntrySelectionState::getFiletype() const
     return m_filetype;
 }
 
+WCFiletype *NWCEntrySelectionState::getEffectiveFiletype() const
+{
+    if ( getFiletype() != NULL ) {
+        return getFiletype();
+    } else {
+        const NWC::FSEntry *fse;
+
+        fse = getNWCEntry();
+
+        if ( fse && fse->isDir( true ) == true ) {
+            return wconfig->getdirtype();
+        } else {
+            return wconfig->getnotyettype();
+        }
+    }
+}
+
 int NWCEntrySelectionState::sortfunction( const NWCEntrySelectionState &e1,
                                           const NWCEntrySelectionState &e2,
                                           int mode )
@@ -240,7 +257,7 @@ int NWCEntrySelectionState::sortfunction( const NWCEntrySelectionState &e1,
                   ft2 = wconfig->getnotyettype();
               }
           }
-          comp = strcmp( ft1->getName(), ft2->getName() );
+          comp = ft1->getName().compare( ft2->getName() );
           if ( comp == 0 )
               comp = fse1->getFullname().compare( fse2->getFullname() );
           break;
