@@ -719,7 +719,7 @@ void SearchOpBG::viewResult()
             //TODO check whether file system exceeds basic textstorage size and ask for increase
             l.push_back( r.getFullname() );
 
-            FileViewer fv;
+            FileViewer fv( m_worker );
             fv.setShowLineNumbers( true );
             fv.view( l, NULL, r.getLineNr(), true );
         }
