@@ -1,6 +1,6 @@
 /* worker_locale.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2016 Ralf Hoffmann.
+ * Copyright (C) 2001-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -27,7 +27,7 @@
 #include "nwc_path.hh"
 #include "datei.h"
 
-#define CATENTRY 1169
+#define CATENTRY 1180
 #define CATCOMENTRY 66
 #define CATFLAGENTRY 59
 
@@ -1274,6 +1274,17 @@ The default value here is the active entry and it's already correctly protected!
   catalog[1166]=dupstring( "<Cursor up> to increase number of days" );
   catalog[1167]=dupstring( "<Cursor down> to decrease number of days" );
   catalog[1168]=dupstring( "In this window you see all files modified at the same day as the newest file in the current directory. The results can be viewed as a virtual directory in the main window. You can also select only specific entries to be panelized. Also, you may choose to list files modified more days in the past." );
+  catalog[1169]=dupstring( "Show recently used entries only" );
+  catalog[1170]=dupstring( "Show recently used entries only (Ctrl-r)" );
+  catalog[1171]=dupstring( "Change filter" );
+  catalog[1172]=dupstring( "hide %s" );
+  catalog[1173]=dupstring( "disable all filters" );
+  catalog[1174]=dupstring( "disable filter %s" );
+  catalog[1175]=dupstring( "Reload file\nKey: Ctrl-r" );
+  catalog[1176]=dupstring( "Show non-printable" );
+  catalog[1177]=dupstring( "Show non-printable characters as hexadecimal representation\ninstead of a simple dot replacement" );
+  catalog[1178]=dupstring( "Show in list view" );
+  catalog[1179]=dupstring( "Open a new tab in the current list view and highlight the currently viewed file" );
 
 //  catalog[]=dupstring( "" );
   
